"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLatestMaps = exports.getMapsByUploader = exports.getMapByHash = exports.getMapByID = void 0;
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const RateLimitError_1 = tslib_1.__importDefault(require("../errors/RateLimitError"));
const SongNotFoundError_1 = tslib_1.__importDefault(require("../errors/SongNotFoundError"));
const beforeRegex = /[\d]{4}-[\d]{2}-[\d]{2}T[\d]{2}:[\d]{2}:[\d]{2}\+[\d]{2}:[\d]{2}/g;
function getMapByID(axiosInstance, id) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get(`/maps/id/${id}`);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 404)
                    throw new SongNotFoundError_1.default('ID', id);
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getMapByID = getMapByID;
function getMapByHash(axiosInstance, hash) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get(`/maps/hash/${hash}`);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 404)
                    throw new SongNotFoundError_1.default('hash', hash);
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getMapByHash = getMapByHash;
function getMapsByUploader(axiosInstance, id, page = 0) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get(`/maps/uploader/${id}/${page}`);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getMapsByUploader = getMapsByUploader;
function getLatestMaps(axiosInstance, automapper, before) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            let endpoint = `/maps/latest?automapper${automapper}`;
            if (before) {
                if (!beforeRegex.test(before))
                    throw new Error('The before parameter needs to be of the form "YYYY-MM-DDTHH:MM:SS+00:00"');
                endpoint += `&before=${encodeURIComponent(before)}`;
            }
            const response = yield axiosInstance.get(endpoint);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getLatestMaps = getLatestMaps;
