"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPlaylistsByUser = exports.getLatestPlaylists = exports.getPlaylistByID = void 0;
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const PlaylistNotFoundError_1 = tslib_1.__importDefault(require("../errors/PlaylistNotFoundError"));
const RateLimitError_1 = tslib_1.__importDefault(require("../errors/RateLimitError"));
const timeRegex = /[\d]{4}-[\d]{2}-[\d]{2}T[\d]{2}:[\d]{2}:[\d]{2}\+[\d]{2}:[\d]{2}/g;
function getPlaylistByID(axiosInstance, id, page = 0) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get(`/playlists/id/${id}`);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 404)
                    throw new PlaylistNotFoundError_1.default(id);
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getPlaylistByID = getPlaylistByID;
function getLatestPlaylists(axiosInstance, after, before, sort) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get('/playlists/latest', {
                params: { after, before, sort },
            });
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getLatestPlaylists = getLatestPlaylists;
function getPlaylistsByUser(axiosInstance, userId, page = 0) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield axiosInstance.get(`/playlists/user/${userId}/${page}`);
            return response.data;
        }
        catch (err) {
            if (axios_1.default.isAxiosError(err)) {
                if (!err.response)
                    throw err;
                const response = err.response;
                if (response.status === 429)
                    throw new RateLimitError_1.default();
            }
            throw err;
        }
    });
}
exports.getPlaylistsByUser = getPlaylistsByUser;
